<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>AppearancePage</name>
    <message>
        <location filename="../appearancepage.ui" line="20"/>
        <source>Style:</source>
        <translation>Стиль:</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="59"/>
        <source>Preview</source>
        <translation>Предварительный просмотр</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="69"/>
        <source>Active palette</source>
        <translation>Активная палитра</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="74"/>
        <source>Inactive palette</source>
        <translation>Неактивная палитра</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="79"/>
        <source>Disabled palette</source>
        <translation>Палитра выключенных элеметнов</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="113"/>
        <source>Palette</source>
        <translation>Палитра</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="124"/>
        <location filename="../appearancepage.cpp" line="83"/>
        <source>Default</source>
        <translation>По умолчанию</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="134"/>
        <source>Custom</source>
        <translation>Изменённая</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="161"/>
        <source>Color scheme:</source>
        <translation>Цветовая схема:</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="187"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="218"/>
        <source>Standard dialogs:</source>
        <translation>Стандартные диалоги:</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="70"/>
        <source>Create</source>
        <translation>Создать</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="71"/>
        <source>Edit</source>
        <translation>Изменить</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="72"/>
        <source>Create a Copy</source>
        <translation>Создать копию</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="73"/>
        <source>Rename</source>
        <translation>Переименовать</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="75"/>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="137"/>
        <location filename="../appearancepage.cpp" line="211"/>
        <location filename="../appearancepage.cpp" line="250"/>
        <source>Enter Color Scheme Name</source>
        <translation>Введите имя цветовой схемы</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="137"/>
        <location filename="../appearancepage.cpp" line="211"/>
        <location filename="../appearancepage.cpp" line="250"/>
        <source>File name:</source>
        <translation>Имя файла:</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="146"/>
        <location filename="../appearancepage.cpp" line="222"/>
        <location filename="../appearancepage.cpp" line="230"/>
        <location filename="../appearancepage.cpp" line="260"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="146"/>
        <location filename="../appearancepage.cpp" line="222"/>
        <location filename="../appearancepage.cpp" line="260"/>
        <source>The color scheme &quot;%1&quot; already exists</source>
        <translation>Цветовая схема &quot;%1&quot; уже существует</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="164"/>
        <location filename="../appearancepage.cpp" line="187"/>
        <location filename="../appearancepage.cpp" line="245"/>
        <source>Warning</source>
        <translation>Предупреждение</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="164"/>
        <location filename="../appearancepage.cpp" line="187"/>
        <location filename="../appearancepage.cpp" line="245"/>
        <source>The color scheme &quot;%1&quot; is read only</source>
        <translation>Цветовая схема &quot;%1&quot; доступна только для чтения</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="192"/>
        <source>Confirm Remove</source>
        <translation>Подтвердите удаление</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="193"/>
        <source>Are you sure you want to remove color scheme &quot;%1&quot;?</source>
        <translation>Вы уверены, что хотите удалить цветовую схему &quot;%1&quot;?</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="213"/>
        <source>%1 (copy)</source>
        <translation>%1 (копия)</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="230"/>
        <source>Unable to copy file</source>
        <translation>Невозможно скопировать файл</translation>
    </message>
</context>
<context>
    <name>FontConfigDialog</name>
    <message>
        <location filename="../fontconfigdialog.ui" line="14"/>
        <location filename="../fontconfigdialog.cpp" line="73"/>
        <source>Font Configuration</source>
        <translation>Настройка шрифтов</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="29"/>
        <source>Disable automatic hinting for bold fonts</source>
        <translation>Отключить автоуточнение для жирных шрифтов</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="36"/>
        <source>LCD filter:</source>
        <translation>Фильтр LCD:</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="43"/>
        <source>Automatic hinting</source>
        <translation>Автоматическое уточнение</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="50"/>
        <source>Hinting</source>
        <translation>Уточнение</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="67"/>
        <source>Font resolution:</source>
        <translation>Разрешение шрифтов:</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="110"/>
        <source> dpi</source>
        <translation> точек/дюйм</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="83"/>
        <source>Subpixel geometry:</source>
        <translation>Геометрия субпикселей:</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="90"/>
        <source>Antialiasing</source>
        <translation>Сглаживание</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="97"/>
        <source>Hinting style:</source>
        <translation>Стиль уточнения:</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.cpp" line="42"/>
        <location filename="../fontconfigdialog.cpp" line="47"/>
        <source>None</source>
        <translation>Выключен</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.cpp" line="43"/>
        <source>Slight</source>
        <translation>Слабое</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.cpp" line="44"/>
        <source>Medium</source>
        <translation>Среднее</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.cpp" line="45"/>
        <source>Full</source>
        <translation>Полное</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.cpp" line="74"/>
        <source>&lt;i&gt;%1&lt;/i&gt; already exists. Do you want to replace it?</source>
        <translation>Файл &lt;i&gt;%1&lt;/i&gt; уже существует. Хотите ли вы его заменить?</translation>
    </message>
</context>
<context>
    <name>FontsPage</name>
    <message>
        <location filename="../fontspage.ui" line="47"/>
        <location filename="../fontspage.ui" line="67"/>
        <location filename="../fontspage.ui" line="86"/>
        <location filename="../fontspage.ui" line="93"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../fontspage.ui" line="60"/>
        <source>General:</source>
        <translation>Общий:</translation>
    </message>
    <message>
        <location filename="../fontspage.ui" line="100"/>
        <source>Fixed width:</source>
        <translation>Фиксированной ширины:</translation>
    </message>
    <message>
        <location filename="../fontspage.ui" line="125"/>
        <source>Create  fonts.conf</source>
        <translation>Создать fonts.conf</translation>
    </message>
    <message>
        <location filename="../fontspage.ui" line="132"/>
        <source>Remove fonts.conf</source>
        <translation>Удалить fonts.conf</translation>
    </message>
    <message>
        <location filename="../fontspage.cpp" line="110"/>
        <source>Remove Font Configuration</source>
        <translation>Удалить настройку шрифтов</translation>
    </message>
    <message>
        <location filename="../fontspage.cpp" line="111"/>
        <source>Are you sure you want to delete &lt;i&gt;%1&lt;/i&gt;?</source>
        <translation>Вы уверены, что хотите удалить &lt;i&gt;%1&lt;/i&gt;?</translation>
    </message>
</context>
<context>
    <name>InterfacePage</name>
    <message>
        <location filename="../interfacepage.ui" line="35"/>
        <source>Double click interval:</source>
        <translation>Интервал двойного щелчка:</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="42"/>
        <source>Cursor flash time:</source>
        <translation>Период мигания курсора:</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="49"/>
        <source>ComboBox effect:</source>
        <translation>Эффект выпадающего списка:</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="56"/>
        <source>ToolTip effect:</source>
        <translation>Эффект подсказки:</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="63"/>
        <source>ToolBox effect:</source>
        <translation>Эффект панели инструментов:</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="70"/>
        <location filename="../interfacepage.ui" line="80"/>
        <source> ms</source>
        <translation> мс</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="94"/>
        <location filename="../interfacepage.ui" line="111"/>
        <location filename="../interfacepage.ui" line="133"/>
        <location filename="../interfacepage.ui" line="157"/>
        <source>Disable</source>
        <translation>Выключен</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="99"/>
        <location filename="../interfacepage.ui" line="116"/>
        <location filename="../interfacepage.ui" line="138"/>
        <location filename="../interfacepage.ui" line="162"/>
        <source>Animate</source>
        <translation>Анимация</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="121"/>
        <location filename="../interfacepage.ui" line="167"/>
        <source>Fade</source>
        <translation>Затухание</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="146"/>
        <source>Menu effect:</source>
        <translation>Эффект меню:</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="175"/>
        <source>Enable gui effects</source>
        <translation>Включить эффекты интерфейса</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="182"/>
        <source>Dialog buttons layout:</source>
        <translation>Расположение кнопок диалога:</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="192"/>
        <source>Keyboard scheme:</source>
        <translation>Стандартные горячие клавиши:</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="202"/>
        <source>Menus have icons</source>
        <translation>Показывать значки в меню</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="209"/>
        <source>Dialog buttons have icons</source>
        <translation>Показывать значки на кнопках диалогов</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="219"/>
        <source>Activate item on single-click</source>
        <translation>Активировать элементы списка одним щелчком</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="229"/>
        <source>Toolbar button style:</source>
        <translation>Стиль кнопок панелей инструментов:</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="239"/>
        <source>Mouse wheel scroll lines:</source>
        <translation>Шаг прокрутки колесом мыши, строк:</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="256"/>
        <source>Show shortcut underlines</source>
        <translation>Подчёркивать клавиатурные сокращения в меню</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="266"/>
        <source>Show shortcuts in context menus</source>
        <translation>Показывать горячие клавиши в контекстных меню</translation>
    </message>
    <message>
        <location filename="../interfacepage.cpp" line="55"/>
        <source>Only display the icon</source>
        <translation>Отображать только значок</translation>
    </message>
    <message>
        <location filename="../interfacepage.cpp" line="56"/>
        <source>Only display the text</source>
        <translation>Отображать только текст</translation>
    </message>
    <message>
        <location filename="../interfacepage.cpp" line="57"/>
        <source>The text appears beside the icon</source>
        <translation>Отображать текст рядом со значком</translation>
    </message>
    <message>
        <location filename="../interfacepage.cpp" line="58"/>
        <source>The text appears under the icon</source>
        <translation>Отображать текст под значком</translation>
    </message>
    <message>
        <location filename="../interfacepage.cpp" line="59"/>
        <source>Follow the application style</source>
        <translation>Определяется стилем приложения</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Qt6 Configuration Tool</source>
        <translation>Средство настройки Qt6</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="54"/>
        <source>The application is not configured correctly.</source>
        <translation>Приложение не настроено.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="61"/>
        <source>Information</source>
        <translation>Информация</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="68"/>
        <source>Hide</source>
        <translation>Скрыть</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="51"/>
        <source>Appearance</source>
        <translation>Внешний вид</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="52"/>
        <source>Fonts</source>
        <translation>Шрифты</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="53"/>
        <source>Icon Theme</source>
        <translation>Стиль значков</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="54"/>
        <source>Interface</source>
        <translation>Интерфейс</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="56"/>
        <source>Style Sheets</source>
        <translation>Таблицы стилей</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="58"/>
        <source>Troubleshooting</source>
        <translation>Устранение проблем</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="65"/>
        <source>Version: %1</source>
        <translation>Версия: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="110"/>
        <source>Warning</source>
        <translation>Предупреждение</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="119"/>
        <source>Please remove the &lt;b&gt;QT_STYLE_OVERRIDE&lt;/b&gt; environment variable (current value: &lt;b&gt;%1&lt;/b&gt;).</source>
        <translation>Пожалуйста, удалите переменную среды &lt;b&gt;QT_STYLE_OVERRIDE&lt;/b&gt; (текущее значение: &lt;b&gt;%1&lt;/b&gt;).</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="125"/>
        <source>The &lt;b&gt;QT_QPA_PLATFORMTHEME&lt;/b&gt; environment variable is not set (required values: &lt;b&gt;qt6ct&lt;/b&gt; or &lt;b&gt;qt5ct&lt;/b&gt;).</source>
        <translation>Переменная среды &lt;b&gt;QT_QPA_PLATFORMTHEME&lt;/b&gt; не установлена (требуемые значения: &lt;b&gt;qt6ct&lt;/b&gt; или &lt;b&gt;qt5ct&lt;/b&gt;).</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="130"/>
        <source>The &lt;b&gt;QT_QPA_PLATFORMTHEME&lt;/b&gt; environment variable is not set correctly (current value: &lt;b&gt;%1&lt;/b&gt;, required values: &lt;b&gt;qt6ct&lt;/b&gt; or &lt;b&gt;qt5ct&lt;/b&gt;).</source>
        <translation>Переменная среды&lt;b&gt;QT_QPA_PLATFORMTHEME&lt;/b&gt; установлена неправильно (текущее значение: &lt;b&gt;%1&lt;/b&gt;, требуемые значения: &lt;b&gt;qt6ct&lt;/b&gt;или &lt;b&gt;qt5ct&lt;/b&gt;).</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="137"/>
        <source>Unable to find &lt;b&gt;libqt6ct-style.so&lt;/b&gt;</source>
        <translation>Не найден &lt;b&gt;libqt6ct-style.so&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="143"/>
        <source>The &lt;b&gt;%1&lt;/b&gt; plugin is compiled against incompatible Qt version (%2).</source>
        <translation>Модуль %1 собран с несовместимой версией Qt (%2).</translation>
    </message>
</context>
<context>
    <name>PaletteEditDialog</name>
    <message>
        <location filename="../paletteeditdialog.ui" line="14"/>
        <source>Palette Editor</source>
        <translation>Редактор палитры</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.ui" line="79"/>
        <source>Reset palette</source>
        <translation>Сбросить палитру</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.ui" line="29"/>
        <source>Build inactive palette</source>
        <translation>Создать неактивную политру</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.ui" line="36"/>
        <source>Build disabled palette</source>
        <translation>Создать &quot;выключенную&quot; палитру</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="48"/>
        <source>Active</source>
        <translation>Активная</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="48"/>
        <source>Inactive</source>
        <translation>Неактивная</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="48"/>
        <source>Disabled</source>
        <translation>Отключенная</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="90"/>
        <source>Dark</source>
        <translation>Тёмный</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="90"/>
        <source>Window text</source>
        <translation>Текст окна</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="90"/>
        <source>Button background</source>
        <translation>Фон кнопки</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="90"/>
        <source>Bright</source>
        <translation>Яркий</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="90"/>
        <source>Less bright</source>
        <translation>Менее яркий</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="90"/>
        <source>Less dark</source>
        <translation>Менее тёмный</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="91"/>
        <source>Window</source>
        <translation>Окно</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="91"/>
        <source>Shadow</source>
        <translation>Тень</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="91"/>
        <source>Bright text</source>
        <translation>Яркий текст</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="91"/>
        <source>Button text</source>
        <translation>Текст кнопки</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="91"/>
        <source>Normal text</source>
        <translation>Обычный текст</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="91"/>
        <source>Normal background</source>
        <translation>Обычный фон</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="92"/>
        <source>Highlight</source>
        <translation>Выделенная область</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="92"/>
        <source>Highlighted text</source>
        <translation>Выделенный текст</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="92"/>
        <source>Visited link</source>
        <translation>Посещённая ссылка</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="93"/>
        <source>Default</source>
        <translation>По умолчанию</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="93"/>
        <source>Tooltip background</source>
        <translation>Фон подсказки</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="93"/>
        <source>Tooltip text</source>
        <translation>Текст подсказки</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="92"/>
        <source>Link</source>
        <translation>Ссылка</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="92"/>
        <source>Alternate background</source>
        <translation>Альтернативный фон</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="93"/>
        <source>Placeholder text</source>
        <translation>Замещающий текст</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="107"/>
        <source>Select Color</source>
        <translation>Выберите цвет</translation>
    </message>
</context>
<context>
    <name>PreviewForm</name>
    <message>
        <location filename="../previewform.ui" line="14"/>
        <source>Preview Window</source>
        <translation>Окно предпросмотра</translation>
    </message>
    <message>
        <location filename="../previewform.ui" line="27"/>
        <source>Tab 1</source>
        <translation>Вкладка 1</translation>
    </message>
    <message>
        <location filename="../previewform.ui" line="36"/>
        <source>PushButton</source>
        <translation>Кнопка</translation>
    </message>
    <message>
        <location filename="../previewform.ui" line="65"/>
        <source>Tab 2</source>
        <translation>Вкладка 2</translation>
    </message>
    <message>
        <location filename="../previewform.ui" line="74"/>
        <source>RadioButton</source>
        <translation>Переключатель</translation>
    </message>
    <message>
        <location filename="../previewform.ui" line="84"/>
        <source>CheckBox</source>
        <translation>Выключатель</translation>
    </message>
</context>
<context>
    <name>QSSEditorDialog</name>
    <message>
        <location filename="../qsseditordialog.cpp" line="46"/>
        <source>%1 - Style Sheet Editor</source>
        <translation>%1 - Редактор таблиц стилей</translation>
    </message>
    <message>
        <location filename="../qsseditordialog.ui" line="14"/>
        <source>Style Sheet Editor</source>
        <translation>Редактор таблиц стилей</translation>
    </message>
</context>
<context>
    <name>QSSPage</name>
    <message>
        <location filename="../qsspage.ui" line="23"/>
        <source>Create</source>
        <translation>Создать</translation>
    </message>
    <message>
        <location filename="../qsspage.ui" line="66"/>
        <location filename="../qsspage.cpp" line="51"/>
        <location filename="../qsspage.cpp" line="87"/>
        <source>Edit</source>
        <translation>Изменить</translation>
    </message>
    <message>
        <location filename="../qsspage.ui" line="76"/>
        <location filename="../qsspage.cpp" line="53"/>
        <source>Rename</source>
        <translation>Переименовать</translation>
    </message>
    <message>
        <location filename="../qsspage.ui" line="33"/>
        <location filename="../qsspage.cpp" line="55"/>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="52"/>
        <source>Create a Copy</source>
        <translation>Создать копию</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="92"/>
        <source>View</source>
        <translation>Просмотр</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="106"/>
        <location filename="../qsspage.cpp" line="251"/>
        <source>File name:</source>
        <translation>Имя файла:</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="106"/>
        <location filename="../qsspage.cpp" line="251"/>
        <source>Enter Style Sheet Name</source>
        <translation>Введите имя таблицы стилей</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="117"/>
        <location filename="../qsspage.cpp" line="218"/>
        <location filename="../qsspage.cpp" line="226"/>
        <location filename="../qsspage.cpp" line="263"/>
        <location filename="../qsspage.cpp" line="271"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="117"/>
        <source>The file &quot;%1&quot; already exists</source>
        <translation>Файл &quot;%1&quot; уже существует</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="151"/>
        <source>Confirm Remove</source>
        <translation>Подтвердите удаление</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="152"/>
        <source>Are you sure you want to remove style sheet &quot;%1&quot;?</source>
        <translation>Вы уверены, что хотите удалить таблицу стилей &quot;%1&quot;?</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="208"/>
        <source>Rename Style Sheet</source>
        <translation>Переименовать таблицу стилей</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="208"/>
        <source>Style sheet name:</source>
        <translation>Имя таблицы стилей:</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="218"/>
        <location filename="../qsspage.cpp" line="263"/>
        <source>The style sheet &quot;%1&quot; already exists</source>
        <translation>Таблица стилей с именем &quot;%1&quot; уже существует</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="226"/>
        <source>Unable to rename file</source>
        <translation>Невозможно переименовать файл</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="253"/>
        <source>%1 (copy).qss</source>
        <translation>%1 (копия).qss</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="271"/>
        <source>Unable to copy file</source>
        <translation>Невозможно скопировать файл</translation>
    </message>
</context>
<context>
    <name>TroubleshootingPage</name>
    <message>
        <location filename="../troubleshootingpage.ui" line="20"/>
        <source>Ignored applications:</source>
        <translation>Игнорируемые приложения:</translation>
    </message>
    <message>
        <location filename="../troubleshootingpage.ui" line="29"/>
        <source>Add...</source>
        <translation>Добавить...</translation>
    </message>
    <message>
        <location filename="../troubleshootingpage.ui" line="40"/>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <location filename="../troubleshootingpage.ui" line="73"/>
        <source>Do not apply any styles and color schemes for the listed applications.</source>
        <translation>Не применять стили и цветовые схемы для перечисленных приложений. </translation>
    </message>
    <message>
        <location filename="../troubleshootingpage.ui" line="82"/>
        <source>Make top-level widgets use pure raster surfaces, and do not support non-native GL-based child widgets.</source>
        <translation>Включает растровые поверхности для виджетов верхнего уровня и отключает поддержку дочерних виджетов на базе GL.</translation>
    </message>
    <message>
        <location filename="../troubleshootingpage.ui" line="85"/>
        <source>Force raster surface</source>
        <translation>Задействовать растровые поверхности</translation>
    </message>
    <message>
        <location filename="../troubleshootingpage.cpp" line="64"/>
        <source>Select Application</source>
        <translation>Выберите приложение</translation>
    </message>
    <message>
        <location filename="../troubleshootingpage.cpp" line="64"/>
        <source>Executable files (*)</source>
        <translation>Исполняемые файлы (*)</translation>
    </message>
</context>
</TS>
